==> haskell-storable-record-0.0.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-record.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-record
version: 0.0.4
id: storable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r
key: storable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-record/
synopsis: Elegant definition of Storable instances for records
description:
    With this package
    you can build a Storable instance of a record type
    from Storable instances of its elements in an elegant way.
    It does not do any magic,
    just a bit arithmetic to compute the right offsets,
    that would be otherwise done manually
    or by a preprocessor like C2HS.
    I cannot promise that the generated memory layout
    is compatible with that of a corresponding C struct.
    However, the module generates the smallest layout
    that is possible with respect to the alignment of the record elements.
    If you encounter, that a record does not have a compatible layout,
    we should fix that.
    But also without C compatibility this package is useful
    e.g. in connection with StorableVector.
    .
    We provide Storable instance support for several cases:
    .
    * If you wrap a type in a @newtype@,
    then you can lift its '\''Storable'\'' instance to that @newtype@
    with the module "Foreign.Storable.Newtype".
    This way you do not need the @GeneralizedNewtypeDeriving@ feature of GHC.
    .
    * If you have a type that is an instance of '\''Traversable'\'',
    you can use that feature for implementation of '\''Storable'\'' methods.
    The module "Foreign.Storable.Traversable"
    allows manipulation of the portion of your type,
    that is accessible by '\''Traversable'\'' methods.
    For instance with the type
    @data T a = Cons Int [a]@
    and an according '\''Traversable'\'' implementation,
    you can load and store the elements of the contained list.
    This may be part of a '\''Storable'\'' implementation of the whole type.
    .
    * If you have a record containing elements of various types,
    then you need module "Foreign.Storable.Record".
    .
    Note however that the Storable instances
    defined with this package are quite slow in (up to) GHC-6.12.1.
    I'\''m afraid this is due to incomplete inlining,
    but we have still to investigate the problem.
    .
    For examples see packages @storable-tuple@ and @sample-frame@.
category: Data, Foreign
abi: 1abdd9ecf110b7cfea207dac4d624762
exposed: True
exposed-modules:
    Foreign.Storable.FixedArray Foreign.Storable.Newtype
    Foreign.Storable.Record Foreign.Storable.Traversable
hidden-modules: Foreign.Storable.RecordMinimalSize
                Foreign.Storable.RecordReaderPtr
                Foreign.Storable.TraversableUnequalSizes
import-dirs: /usr/lib/ghc-8.4.3/site-local/storable-record-0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/storable-record-0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/storable-record-0.0.4
hs-libraries: HSstorable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r
depends:
    base-4.11.1.0 transformers-0.5.5.0
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=632b3d47f82599a1155bed59f183b750
haddock-interfaces: /usr/share/doc/haskell-storable-record/html/storable-record.haddock
haddock-html: /usr/share/doc/haskell-storable-record/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-record-0.0.4-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-record.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-record
version: 0.0.4
id: storable-record-0.0.4-KSfqnxV0wCrDxvYLXFw5z3
key: storable-record-0.0.4-KSfqnxV0wCrDxvYLXFw5z3
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-record/
synopsis: Elegant definition of Storable instances for records
description:
    With this package
    you can build a Storable instance of a record type
    from Storable instances of its elements in an elegant way.
    It does not do any magic,
    just a bit arithmetic to compute the right offsets,
    that would be otherwise done manually
    or by a preprocessor like C2HS.
    I cannot promise that the generated memory layout
    is compatible with that of a corresponding C struct.
    However, the module generates the smallest layout
    that is possible with respect to the alignment of the record elements.
    If you encounter, that a record does not have a compatible layout,
    we should fix that.
    But also without C compatibility this package is useful
    e.g. in connection with StorableVector.
    .
    We provide Storable instance support for several cases:
    .
    * If you wrap a type in a @newtype@,
    then you can lift its '\''Storable'\'' instance to that @newtype@
    with the module "Foreign.Storable.Newtype".
    This way you do not need the @GeneralizedNewtypeDeriving@ feature of GHC.
    .
    * If you have a type that is an instance of '\''Traversable'\'',
    you can use that feature for implementation of '\''Storable'\'' methods.
    The module "Foreign.Storable.Traversable"
    allows manipulation of the portion of your type,
    that is accessible by '\''Traversable'\'' methods.
    For instance with the type
    @data T a = Cons Int [a]@
    and an according '\''Traversable'\'' implementation,
    you can load and store the elements of the contained list.
    This may be part of a '\''Storable'\'' implementation of the whole type.
    .
    * If you have a record containing elements of various types,
    then you need module "Foreign.Storable.Record".
    .
    Note however that the Storable instances
    defined with this package are quite slow in (up to) GHC-6.12.1.
    I'\''m afraid this is due to incomplete inlining,
    but we have still to investigate the problem.
    .
    For examples see packages @storable-tuple@ and @sample-frame@.
category: Data, Foreign
abi: 4fd1c6bd76568f91ae4fe358f254de1e
exposed: True
exposed-modules:
    Foreign.Storable.FixedArray Foreign.Storable.Newtype
    Foreign.Storable.Record Foreign.Storable.Traversable
hidden-modules: Foreign.Storable.RecordMinimalSize
                Foreign.Storable.RecordReaderPtr
                Foreign.Storable.TraversableUnequalSizes
import-dirs: /usr/lib/ghc-8.6.1/site-local/storable-record-0.0.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/storable-record-0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/storable-record-0.0.4
hs-libraries: HSstorable-record-0.0.4-KSfqnxV0wCrDxvYLXFw5z3
depends:
    base-4.12.0.0 transformers-0.5.5.0
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-record/html/storable-record.haddock
haddock-html: /usr/share/doc/haskell-storable-record/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
